@@ -10,11 +10,22 @@ class Accessor():
     def set_db(cls, db):
         Accessor.db = db
 
+    @classmethod
+    def models(cls):
+        return [
+            v for v in Accessor.get_db().Model._decl_class_registry.values()
+            if hasattr(v, '__table__')
+        ]
+
+    @classmethod
+    def model_from_table_name(cls, name):
+        for model in Accessor.models():
+            if model.__name__ == name:
+                return model
+
     @classmethod
     def model_from_table_name(cls, table_name):
-        for model in Accessor.get_db().Model._decl_class_registry.values():
-            if not hasattr(model, '__table__'):
-                continue
+        for model in Accessor.models():
             if model.__tablename__ == table_name:
                 return model
 
